//
// backscale.cc
//
// Authors:  Richard Saxton (VEGA/ESA)
//           ESA XMM SOC
//
// Description: Metatask for running arfgen to produce BACKSCAL keyword
//
//#include <set>          // C++
//#include <algorithm>
//#include <strstream.h>
//#include <unistd.h>
#include <Tracer.h>
#include <metatask.h>
#include <errstr.h>
#include <param.h>

#include <arfgen.h>   // tasks

#include "backscale.h"

void backscale()
{
  PROC

  /* Get the parameters from this command line */
    string spectrumset = stringParameter("spectrumset");
    bool withbadpixcorr = booleanParameter("withbadpixcorr");
    bool useodfatt = booleanParameter("useodfatt");
    string badpixlocation = stringParameter("badpixlocation");

  /* Set up the parameters for calling arfgen */
    openParameters("arfgen");

  /* First the input parameters */
    setParameter("spectrumset",spectrumset);
    setParameter("withbadpixcorr",withbadpixcorr);
    setParameter("useodfatt",useodfatt);
    setParameter("badpixlocation",badpixlocation);

  /* Set the other parameters */
    setParameter("withrmfset",false);
    setParameter("arfset","deletearf.ds");
    setParameter("withdetbounds",false);
    setParameter("detxbins",1);            // Use the minimum detector map
    setParameter("detybins",1);
    setParameter("detmaptype","flat");
    setParameter("extendedsource",true);   // Use extended source logic
    setParameter("modeleffarea",false);
    setParameter("modelquantumeff",false);
    setParameter("modelfiltertrans",false);
    setParameter("modelee",false);
    setParameter("setbackscale",true); // Set the backscale value
    setParameter("keeparfset",false); // Throw away the generated arf file

  /* Now run arfgen using these parameters */ 
    task(arfgen);
   
  /* Shutdown */
    closeParameters();

  ENDPROC
}

